@@ -360,6 +360,156 @@ class AsyncEthModuleTest:
         transaction = block['transactions'][0]
         assert transaction['hash'] == block_with_txn['transactions'][0]
 
+    @pytest.mark.asyncio
+    async def test_eth_get_raw_transaction(
+        self, async_w3: "Web3", mined_txn_hash: HexStr
+    ) -> None:
+        raw_transaction = await async_w3.eth.get_raw_transaction(mined_txn_hash)  # type: ignore
+        assert is_bytes(raw_transaction)
+
+    @pytest.mark.asyncio
+    async def test_eth_get_raw_transaction_raises_error(
+        self, web3: "Web3", mined_txn_hash: HexStr
+    ) -> None:
+        with pytest.raises(TransactionNotFound, match=f"Transaction with hash: '{UNKNOWN_HASH}'"):
+            web3.eth.get_raw_transaction(UNKNOWN_HASH)
+
+    @pytest.mark.asyncio
+    async def test_eth_get_balance(self, async_w3: "Web3") -> None:
+        coinbase = await async_w3.eth.coinbase  # type: ignore
+
+        with pytest.raises(InvalidAddress):
+            await async_w3.eth.get_balance(  # type: ignore
+                ChecksumAddress(HexAddress(HexStr(coinbase.lower())))
+            )
+
+        balance = await async_w3.eth.get_balance(coinbase)  # type: ignore
+
+        assert is_integer(balance)
+        assert balance >= 0
+
+    @pytest.mark.asyncio
+    async def test_eth_get_code(
+        self, async_w3: "Web3", math_contract_address: ChecksumAddress
+    ) -> None:
+        code = await async_w3.eth.get_code(math_contract_address)  # type: ignore
+        assert isinstance(code, HexBytes)
+        assert len(code) > 0
+
+    @pytest.mark.asyncio
+    async def test_eth_get_code_invalid_address(
+        self, async_w3: "Web3", math_contract: "Contract"
+    ) -> None:
+        with pytest.raises(InvalidAddress):
+            await async_w3.eth.get_code(  # type: ignore
+                ChecksumAddress(HexAddress(HexStr(math_contract.address.lower())))
+            )
+
+    @pytest.mark.asyncio
+    async def test_eth_get_code_with_block_identifier(
+        self, async_w3: "Web3", emitter_contract: "Contract"
+    ) -> None:
+        block_id = await async_w3.eth.block_number  # type: ignore
+        code = await async_w3.eth.get_code(emitter_contract.address, block_id)  # type: ignore
+        assert isinstance(code, HexBytes)
+        assert len(code) > 0
+
+    @pytest.mark.asyncio
+    async def test_eth_get_transaction_count(
+        self, async_w3: "Web3", unlocked_account_dual_type: ChecksumAddress
+    ) -> None:
+        transaction_count = await async_w3.eth.get_transaction_count(unlocked_account_dual_type)  # type: ignore # noqa E501
+        assert is_integer(transaction_count)
+        assert transaction_count >= 0
+
+    @pytest.mark.asyncio
+    async def test_eth_call(
+        self, async_w3: "Web3", math_contract: "Contract"
+    ) -> None:
+        coinbase = await async_w3.eth.coinbase  # type: ignore
+        txn_params = math_contract._prepare_transaction(
+            fn_name='add',
+            fn_args=(7, 11),
+            transaction={'from': coinbase, 'to': math_contract.address},
+        )
+        call_result = await async_w3.eth.call(txn_params)  # type: ignore
+        assert is_string(call_result)
+        result = async_w3.codec.decode_single('uint256', call_result)
+        assert result == 18
+
+    @pytest.mark.asyncio
+    async def test_eth_call_with_override(
+        self, async_w3: "Web3", revert_contract: "Contract"
+    ) -> None:
+        coinbase = await async_w3.eth.coinbase  # type: ignore
+        txn_params = revert_contract._prepare_transaction(
+            fn_name='normalFunction',
+            transaction={'from': coinbase, 'to': revert_contract.address},
+        )
+        call_result = await async_w3.eth.call(txn_params)  # type: ignore
+        result = async_w3.codec.decode_single('bool', call_result)
+        assert result is True
+
+        # override runtime bytecode: `normalFunction` returns `false`
+        override_code = '0x6080604052348015600f57600080fd5b5060043610603c5760003560e01c8063185c38a4146041578063c06a97cb146049578063d67e4b84146051575b600080fd5b60476071565b005b604f60df565b005b605760e4565b604051808215151515815260200191505060405180910390f35b6040517f08c379a000000000000000000000000000000000000000000000000000000000815260040180806020018281038252601b8152602001807f46756e6374696f6e20686173206265656e2072657665727465642e000000000081525060200191505060405180910390fd5b600080fd5b60008090509056fea2646970667358221220bb71e9e9a2e271cd0fbe833524a3ea67df95f25ea13aef5b0a761fa52b538f1064736f6c63430006010033'  # noqa: E501
+        call_result = await async_w3.eth.call(  # type: ignore
+            txn_params,
+            'latest',
+            {revert_contract.address: {'code': override_code}}
+        )
+        result = async_w3.codec.decode_single('bool', call_result)
+        assert result is False
+
+    @pytest.mark.asyncio
+    async def test_eth_call_with_0_result(
+        self, async_w3: "Web3", math_contract: "Contract"
+    ) -> None:
+        coinbase = await async_w3.eth.coinbase  # type: ignore
+        txn_params = math_contract._prepare_transaction(
+            fn_name='add',
+            fn_args=(0, 0),
+            transaction={'from': coinbase, 'to': math_contract.address},
+        )
+        call_result = await async_w3.eth.call(txn_params)  # type: ignore
+        assert is_string(call_result)
+        result = async_w3.codec.decode_single('uint256', call_result)
+        assert result == 0
+
+    @pytest.mark.asyncio
+    async def test_eth_call_revert_with_msg(
+        self,
+        async_w3: "Web3",
+        revert_contract: "Contract",
+        unlocked_account: ChecksumAddress,
+    ) -> None:
+        with pytest.raises(ContractLogicError,
+                           match='execution reverted: Function has been reverted'):
+            txn_params = revert_contract._prepare_transaction(
+                fn_name="revertWithMessage",
+                transaction={
+                    "from": unlocked_account,
+                    "to": revert_contract.address,
+                },
+            )
+            await async_w3.eth.call(txn_params)  # type: ignore
+
+    @pytest.mark.asyncio
+    async def test_eth_call_revert_without_msg(
+        self,
+        async_w3: "Web3",
+        revert_contract: "Contract",
+        unlocked_account: ChecksumAddress,
+    ) -> None:
+        with pytest.raises(ContractLogicError, match="execution reverted"):
+            txn_params = revert_contract._prepare_transaction(
+                fn_name="revertWithoutMessage",
+                transaction={
+                    "from": unlocked_account,
+                    "to": revert_contract.address,
+                },
+            )
+            await async_w3.eth.call(txn_params)  # type: ignore
+
 
 class EthModuleTest:
     def test_eth_protocol_version(self, web3: "Web3") -> None:
@@ -877,7 +1027,11 @@ class EthModuleTest:
                 json.loads(invalid_typed_message)
             )
 
-    def test_eth_sign_transaction(self, web3: "Web3", unlocked_account: ChecksumAddress) -> None:
+    def test_eth_sign_transaction_legacy(
+        self,
+        web3: "Web3",
+        unlocked_account: ChecksumAddress
+    ) -> None:
         txn_params: TxParams = {
             'from': unlocked_account,
             'to': unlocked_account,
@@ -895,6 +1049,56 @@ class EthModuleTest:
         assert result['tx']['gasPrice'] == txn_params['gasPrice']
         assert result['tx']['nonce'] == txn_params['nonce']
 
+    def test_eth_sign_transaction(
+        self,
+        web3: "Web3",
+        unlocked_account: ChecksumAddress
+    ) -> None:
+        txn_params: TxParams = {
+            'from': unlocked_account,
+            'to': unlocked_account,
+            'value': Wei(1),
+            'gas': Wei(21000),
+            'maxFeePerGas': web3.toWei(2, 'gwei'),
+            'maxPriorityFeePerGas': web3.toWei(1, 'gwei'),
+            'nonce': Nonce(0),
+        }
+        result = web3.eth.sign_transaction(txn_params)
+        signatory_account = web3.eth.account.recover_transaction(result['raw'])
+        assert unlocked_account == signatory_account
+        assert result['tx']['to'] == txn_params['to']
+        assert result['tx']['value'] == txn_params['value']
+        assert result['tx']['gas'] == txn_params['gas']
+        assert result['tx']['maxFeePerGas'] == txn_params['maxFeePerGas']
+        assert result['tx']['maxPriorityFeePerGas'] == txn_params['maxPriorityFeePerGas']
+        assert result['tx']['nonce'] == txn_params['nonce']
+
+    def test_eth_sign_transaction_hex_fees(
+        self,
+        web3: "Web3",
+        unlocked_account: ChecksumAddress
+    ) -> None:
+        txn_params: TxParams = {
+            'from': unlocked_account,
+            'to': unlocked_account,
+            'value': Wei(1),
+            'gas': Wei(21000),
+            'maxFeePerGas': hex(web3.toWei(2, 'gwei')),
+            'maxPriorityFeePerGas': hex(web3.toWei(1, 'gwei')),
+            'nonce': Nonce(0),
+        }
+        result = web3.eth.sign_transaction(txn_params)
+        signatory_account = web3.eth.account.recover_transaction(result['raw'])
+        assert unlocked_account == signatory_account
+        assert result['tx']['to'] == txn_params['to']
+        assert result['tx']['value'] == txn_params['value']
+        assert result['tx']['gas'] == txn_params['gas']
+        assert result['tx']['maxFeePerGas'] == int(str(txn_params['maxFeePerGas']), 16)
+        assert result['tx']['maxPriorityFeePerGas'] == int(
+            str(txn_params['maxPriorityFeePerGas']), 16
+        )
+        assert result['tx']['nonce'] == txn_params['nonce']
+
     def test_eth_signTransaction_deprecated(self,
                                             web3: "Web3",
                                             unlocked_account: ChecksumAddress) -> None:
@@ -926,7 +1130,8 @@ class EthModuleTest:
                 'to': 'unlocked-account.eth',
                 'value': Wei(1),
                 'gas': Wei(21000),
-                'gasPrice': web3.eth.gas_price,
+                'maxFeePerGas': web3.toWei(2, 'gwei'),
+                'maxPriorityFeePerGas': web3.toWei(1, 'gwei'),
                 'nonce': Nonce(0),
             }
             result = web3.eth.sign_transaction(txn_params)
@@ -935,7 +1140,8 @@ class EthModuleTest:
             assert result['tx']['to'] == unlocked_account
             assert result['tx']['value'] == txn_params['value']
             assert result['tx']['gas'] == txn_params['gas']
-            assert result['tx']['gasPrice'] == txn_params['gasPrice']
+            assert result['tx']['maxFeePerGas'] == txn_params['maxFeePerGas']
+            assert result['tx']['maxPriorityFeePerGas'] == txn_params['maxPriorityFeePerGas']
             assert result['tx']['nonce'] == txn_params['nonce']
 
     def test_eth_send_transaction_addr_checksum_required(
@@ -1821,6 +2027,10 @@ class EthModuleTest:
         assert receipt['from'] is not None
         assert is_checksum_address(receipt['from'])
 
+        effective_gas_price = receipt['effectiveGasPrice']
+        assert isinstance(effective_gas_price, int)
+        assert effective_gas_price > 0
+
     def test_eth_getTransactionReceipt_mined_deprecated(
         self, web3: "Web3", block_with_txn: BlockData, mined_txn_hash: HexStr
     ) -> None:
@@ -2168,3 +2378,15 @@ class EthModuleTest:
                           match="submitWork is deprecated in favor of submit_work"):
             result = web3.eth.submitWork(nonce, pow_hash, mix_digest)
         assert result is False
+
+    def test_eth_get_raw_transaction(
+        self, web3: "Web3", mined_txn_hash: HexStr
+    ) -> None:
+        raw_transaction = web3.eth.get_raw_transaction(mined_txn_hash)
+        assert is_bytes(raw_transaction)
+
+    def test_eth_get_raw_transaction_raises_error(
+        self, web3: "Web3", mined_txn_hash: HexStr
+    ) -> None:
+        with pytest.raises(TransactionNotFound, match=f"Transaction with hash: '{UNKNOWN_HASH}'"):
+            web3.eth.get_raw_transaction(UNKNOWN_HASH)
